summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-08-22 11:19:52 +0200
committerNoel Grandin <noel@peralex.com>2016-08-23 09:54:16 +0200
commite0b61fdd35462ff679743dff1203fb5dd50e86a4 (patch)
tree46720d942ff6c656da2b79204294469510591d69
parentba263e124ce263c3c893542062d9c473f5aae589 (diff)
convert SdrIterMode to scoped enum
Change-Id: Iaa4631039e6b96627d8e547f21136f107e157d8a
-rw-r--r--chart2/source/controller/main/ChartController_Tools.cxx2
-rw-r--r--chart2/source/controller/main/ChartTransferable.cxx2
-rw-r--r--chart2/source/controller/main/SelectionHelper.cxx8
-rw-r--r--filter/source/msfilter/svdfppt.cxx8
-rw-r--r--include/svx/svditer.hxx16
-rw-r--r--reportdesign/source/ui/misc/UITools.cxx4
-rw-r--r--reportdesign/source/ui/report/ReportSection.cxx2
-rw-r--r--reportdesign/source/ui/report/dlgedfunc.cxx2
-rw-r--r--sc/source/core/data/documen5.cxx16
-rw-r--r--sc/source/core/data/documen9.cxx14
-rw-r--r--sc/source/core/data/document.cxx2
-rw-r--r--sc/source/core/data/drwlayer.cxx18
-rw-r--r--sc/source/core/tool/charthelper.cxx12
-rw-r--r--sc/source/core/tool/chartlock.cxx2
-rw-r--r--sc/source/core/tool/detfunc.cxx12
-rw-r--r--sc/source/filter/excel/xiescher.cxx2
-rw-r--r--sc/source/filter/html/htmlexp2.cxx2
-rw-r--r--sc/source/ui/app/client.cxx2
-rw-r--r--sc/source/ui/app/drwtrans.cxx12
-rw-r--r--sc/source/ui/drawfunc/fupoor.cxx2
-rw-r--r--sc/source/ui/drawfunc/fusel2.cxx4
-rw-r--r--sc/source/ui/navipi/content.cxx6
-rw-r--r--sc/source/ui/uitest/uiobject.cxx2
-rw-r--r--sc/source/ui/undo/undotab.cxx2
-rw-r--r--sc/source/ui/unoobj/chartuno.cxx8
-rw-r--r--sc/source/ui/unoobj/docuno.cxx2
-rw-r--r--sc/source/ui/unoobj/viewuno.cxx2
-rw-r--r--sc/source/ui/view/dbfunc4.cxx2
-rw-r--r--sc/source/ui/view/drawvie4.cxx4
-rw-r--r--sc/source/ui/view/drawview.cxx6
-rw-r--r--sc/source/ui/view/tabvwshb.cxx2
-rw-r--r--sc/source/ui/view/viewfun5.cxx4
-rw-r--r--sc/source/ui/view/viewfun7.cxx2
-rw-r--r--sd/source/core/CustomAnimationCloner.cxx4
-rw-r--r--sd/source/core/drawdoc2.cxx4
-rw-r--r--sd/source/core/drawdoc4.cxx6
-rw-r--r--sd/source/core/sdpage2.cxx6
-rw-r--r--sd/source/filter/html/htmlex.cxx4
-rw-r--r--sd/source/filter/ppt/pptin.cxx2
-rw-r--r--sd/source/ui/app/sdxfer.cxx2
-rw-r--r--sd/source/ui/dlg/sdtreelb.cxx8
-rw-r--r--sd/source/ui/func/fupoor.cxx4
-rw-r--r--sd/source/ui/unoidl/unopage.cxx8
-rw-r--r--sd/source/ui/view/OutlinerIterator.cxx8
-rw-r--r--sd/source/ui/view/drviews4.cxx2
-rw-r--r--svx/source/customshapes/EnhancedCustomShape3d.cxx2
-rw-r--r--svx/source/customshapes/EnhancedCustomShapeEngine.cxx2
-rw-r--r--svx/source/customshapes/EnhancedCustomShapeFontWork.cxx2
-rw-r--r--svx/source/engine3d/helperhittest3d.cxx2
-rw-r--r--svx/source/engine3d/scene3d.cxx4
-rw-r--r--svx/source/engine3d/view3d.cxx12
-rw-r--r--svx/source/form/fmvwimp.cxx2
-rw-r--r--svx/source/sdr/properties/e3dsceneproperties.cxx2
-rw-r--r--svx/source/sdr/properties/itemsettools.cxx2
-rw-r--r--svx/source/sdr/properties/properties.cxx2
-rw-r--r--svx/source/svdraw/svdedtv1.cxx6
-rw-r--r--svx/source/svdraw/svdedtv2.cxx16
-rw-r--r--svx/source/svdraw/svdfmtf.cxx4
-rw-r--r--svx/source/svdraw/svditer.cxx4
-rw-r--r--svx/source/svdraw/svdpage.cxx4
-rw-r--r--svx/source/svdraw/svdsnpv.cxx4
-rw-r--r--svx/source/unodraw/unoshap3.cxx2
-rw-r--r--sw/source/core/doc/docdraw.cxx4
-rw-r--r--sw/source/core/draw/dcontact.cxx2
-rw-r--r--sw/source/core/frmedt/feshview.cxx4
-rw-r--r--sw/source/core/unocore/unodraw.cxx2
-rw-r--r--sw/source/uibase/dochdl/swdtflvr.cxx2
-rw-r--r--sw/source/uibase/shells/drwbassh.cxx2
68 files changed, 166 insertions, 166 deletions
diff --git a/chart2/source/controller/main/ChartController_Tools.cxx b/chart2/source/controller/main/ChartController_Tools.cxx
index 8eb20b561889..7249095f6927 100644
--- a/chart2/source/controller/main/ChartController_Tools.cxx
+++ b/chart2/source/controller/main/ChartController_Tools.cxx
@@ -387,7 +387,7 @@ void ChartController::impl_PasteShapes( SdrModel* pModel )
for ( sal_uInt16 i = 0; i < nCount; ++i )
{
const SdrPage* pPage = pModel->GetPage( i );
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
while ( aIter.IsMore() )
{
SdrObject* pObj = aIter.Next();
diff --git a/chart2/source/controller/main/ChartTransferable.cxx b/chart2/source/controller/main/ChartTransferable.cxx
index 206b7adf7328..b427669a459c 100644
--- a/chart2/source/controller/main/ChartTransferable.cxx
+++ b/chart2/source/controller/main/ChartTransferable.cxx
@@ -122,7 +122,7 @@ bool ChartTransferable::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, voi
for ( sal_uInt16 i = 0; i < nCount; ++i )
{
const SdrPage* pPage = pMarkedObjModel->GetPage( i );
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
while ( aIter.IsMore() )
{
SdrObject* pObj = aIter.Next();
diff --git a/chart2/source/controller/main/SelectionHelper.cxx b/chart2/source/controller/main/SelectionHelper.cxx
index aa617af60e6c..5f3739970449 100644
--- a/chart2/source/controller/main/SelectionHelper.cxx
+++ b/chart2/source/controller/main/SelectionHelper.cxx
@@ -489,7 +489,7 @@ SdrObject* SelectionHelper::getMarkHandlesObject( SdrObject* pObj )
SdrObjList* pSubList = pObj->GetSubList();
if(pSubList)
{
- SdrObjListIter aIterator(*pSubList, IM_FLAT);
+ SdrObjListIter aIterator(*pSubList, SdrIterMode::Flat);
while (aIterator.IsMore())
{
SdrObject* pMarkHandles = SelectionHelper::getMarkHandlesObject( aIterator.Next() );
@@ -514,7 +514,7 @@ SdrObject* SelectionHelper::getObjectToMark()
SdrObjList* pSubList = pObj->GetSubList();
if(pSubList)
{
- SdrObjListIter aIterator(*pSubList, IM_FLAT);
+ SdrObjListIter aIterator(*pSubList, SdrIterMode::Flat);
while (aIterator.IsMore())
{
SdrObject* pMarkHandles = SelectionHelper::getMarkHandlesObject( aIterator.Next() );
@@ -545,7 +545,7 @@ E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
SdrObjList* pSubList = pObj->GetSubList();
if(pSubList)
{
- SdrObjListIter aIterator(*pSubList, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIterator(*pSubList, SdrIterMode::DeepWithGroups);
while( aIterator.IsMore() && !pRotateable )
{
SdrObject* pSubObj = aIterator.Next();
@@ -634,7 +634,7 @@ bool SelectionHelper::getMarkHandles( SdrHdlList& rHdlList )
return false;
}
- SdrObjListIter aIterator(*pSubList, IM_FLAT);
+ SdrObjListIter aIterator(*pSubList, SdrIterMode::Flat);
while (aIterator.IsMore())
{
diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index 1ab146ee08fe..5590875f88c9 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -1257,7 +1257,7 @@ SdrObject* SdrEscherImport::ProcessObj( SvStream& rSt, DffObjData& rObjData, voi
if ( pOriginalObj && dynamic_cast< const SdrObjGroup* >(pRet) != nullptr )
{ /* check if the original object from the escherimport is part of the group object,
if this is the case, we will use the original object to connect to */
- SdrObjListIter aIter( *pRet, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pRet, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pPartObj = aIter.Next();
@@ -7587,7 +7587,7 @@ SdrObject* SdrPowerPointImport::CreateTable( SdrObject* pGroup, sal_uInt32* pTab
std::set< sal_Int32 > aRows;
std::set< sal_Int32 > aColumns;
- SdrObjListIter aGroupIter( *pSubList, IM_DEEPNOGROUPS, false );
+ SdrObjListIter aGroupIter( *pSubList, SdrIterMode::DeepNoGroups, false );
while( aGroupIter.IsMore() )
{
const SdrObject* pObj( aGroupIter.Next() );
@@ -7687,7 +7687,7 @@ SdrObject* SdrPowerPointImport::CreateTable( SdrObject* pGroup, sal_uInt32* pTab
pPtr->pBObj = nullptr;
// check connections to all its subobjects
- SdrObjListIter aIter( *pGroup, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pGroup, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pPartObj = aIter.Next();
@@ -7713,7 +7713,7 @@ SdrObject* SdrPowerPointImport::CreateTable( SdrObject* pGroup, sal_uInt32* pTab
pRet = pTable;
//Remove Objects from shape map
- SdrObjListIter aIter( *pGroup, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pGroup, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pPartObj = aIter.Next();
diff --git a/reportdesign/source/ui/misc/UITools.cxx b/reportdesign/source/ui/misc/UITools.cxx
index 773a7ce5fe41..101b30173c7f 100644
--- a/reportdesign/source/ui/misc/UITools.cxx
+++ b/reportdesign/source/ui/misc/UITools.cxx
@@ -844,7 +844,7 @@ void notifySystemWindow(vcl::Window* _pWindow, vcl::Window* _pToRegister, const
SdrObject* isOver(const Rectangle& _rRect, SdrPage& _rPage, SdrView& _rView, bool _bAllObjects, SdrObject* _pIgnore, sal_Int16 _nIgnoreType)
{
SdrObject* pOverlappedObj = nullptr;
- SdrObjListIter aIter(_rPage,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(_rPage,SdrIterMode::DeepNoGroups);
SdrObject* pObjIter = nullptr;
while( !pOverlappedObj && (pObjIter = aIter.Next()) != nullptr )
@@ -885,7 +885,7 @@ bool checkArrayForOccurrence(SdrObject* _pObjToCheck, SdrUnoObj* _pIgnore[], int
SdrObject* isOver(const Rectangle& _rRect,SdrPage& _rPage,SdrView& _rView,bool _bAllObjects, SdrUnoObj * _pIgnoreList[], int _nIgnoreListLength)
{
SdrObject* pOverlappedObj = nullptr;
- SdrObjListIter aIter(_rPage,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(_rPage,SdrIterMode::DeepNoGroups);
SdrObject* pObjIter = nullptr;
while( !pOverlappedObj && (pObjIter = aIter.Next()) != nullptr )
diff --git a/reportdesign/source/ui/report/ReportSection.cxx b/reportdesign/source/ui/report/ReportSection.cxx
index b2b2f8871444..07c604f43971 100644
--- a/reportdesign/source/ui/report/ReportSection.cxx
+++ b/reportdesign/source/ui/report/ReportSection.cxx
@@ -417,7 +417,7 @@ void OReportSection::SelectAll(const sal_uInt16 _nObjectType)
else
{
m_pView->UnmarkAll();
- SdrObjListIter aIter(*m_pPage,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*m_pPage,SdrIterMode::DeepNoGroups);
SdrObject* pObjIter = nullptr;
while( (pObjIter = aIter.Next()) != nullptr )
{
diff --git a/reportdesign/source/ui/report/dlgedfunc.cxx b/reportdesign/source/ui/report/dlgedfunc.cxx
index cf583d73b4e5..d6603e299103 100644
--- a/reportdesign/source/ui/report/dlgedfunc.cxx
+++ b/reportdesign/source/ui/report/dlgedfunc.cxx
@@ -577,7 +577,7 @@ bool DlgEdFunc::isRectangleHit(const MouseEvent& rMEvt)
const SdrDragStat& rDragStat = m_rView.GetDragStat();
if (rDragStat.GetDragMethod() != nullptr)
{
- SdrObjListIter aIter(*m_pParent->getPage(),IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*m_pParent->getPage(),SdrIterMode::DeepNoGroups);
SdrObject* pObjIter = nullptr;
// loop through all marked objects and check if there new rect overlapps an old one.
while( (pObjIter = aIter.Next()) != nullptr && !bIsSetPoint)
diff --git a/sc/source/core/data/documen5.cxx b/sc/source/core/data/documen5.cxx
index 66d8dcd15b3f..65d9f9ca5a1c 100644
--- a/sc/source/core/data/documen5.cxx
+++ b/sc/source/core/data/documen5.cxx
@@ -125,7 +125,7 @@ void ScDocument::UpdateAllCharts()
OSL_ENSURE(pPage,"Page ?");
ScRange aRange;
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -192,7 +192,7 @@ bool ScDocument::HasChartAtPoint( SCTAB nTab, const Point& rPos, OUString& rName
SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -237,7 +237,7 @@ uno::Reference< chart2::XChartDocument > ScDocument::GetChartByName( const OUStr
SdrPage* pPage = pDrawLayer->GetPage(nTab);
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -302,7 +302,7 @@ void ScDocument::GetOldChartParameters( const OUString& rName,
SdrPage* pPage = pDrawLayer->GetPage(nTab);
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -349,7 +349,7 @@ void ScDocument::UpdateChartArea( const OUString& rChartName,
SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -584,7 +584,7 @@ void ScDocument::SetChartRangeList( const OUString& rChartName,
SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -639,7 +639,7 @@ uno::Reference< embed::XEmbeddedObject >
SdrPage* pPage = pDrawLayer->GetPage(nTab);
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -678,7 +678,7 @@ void ScDocument::UpdateChartListenerCollection()
if (!pPage)
continue;
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
ScChartListenerCollection::StringSetType& rNonOleObjects =
pChartListenerCollection->getNonOleObjectNames();
diff --git a/sc/source/core/data/documen9.cxx b/sc/source/core/data/documen9.cxx
index 984f21eeb311..4ad9532c62a9 100644
--- a/sc/source/core/data/documen9.cxx
+++ b/sc/source/core/data/documen9.cxx
@@ -91,7 +91,7 @@ void ScDocument::TransferDrawPage(ScDocument* pSrcDoc, SCTAB nSrcPos, SCTAB nDes
if (pOldPage && pNewPage)
{
- SdrObjListIter aIter( *pOldPage, IM_FLAT );
+ SdrObjListIter aIter( *pOldPage, SdrIterMode::Flat );
SdrObject* pOldObject = aIter.Next();
while (pOldObject)
{
@@ -315,7 +315,7 @@ bool ScDocument::HasOLEObjectsInArea( const ScRange& rRange, const ScMarkData* p
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -341,7 +341,7 @@ void ScDocument::StartAnimations( SCTAB nTab, vcl::Window* pWin )
if (!pPage)
return;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -370,7 +370,7 @@ bool ScDocument::HasBackgroundDraw( SCTAB nTab, const Rectangle& rMMRect ) const
bool bFound = false;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
@@ -395,7 +395,7 @@ bool ScDocument::HasAnyDraw( SCTAB nTab, const Rectangle& rMMRect ) const
bool bFound = false;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
@@ -423,7 +423,7 @@ SdrObject* ScDocument::GetObjectAtPoint( SCTAB nTab, const Point& rPos )
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -548,7 +548,7 @@ bool ScDocument::HasDetectiveObjects(SCTAB nTab) const
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
diff --git a/sc/source/core/data/document.cxx b/sc/source/core/data/document.cxx
index 2b1130336982..da102960eb49 100644
--- a/sc/source/core/data/document.cxx
+++ b/sc/source/core/data/document.cxx
@@ -995,7 +995,7 @@ void ScDocument::SetLayoutRTL( SCTAB nTab, bool bRTL )
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/core/data/drwlayer.cxx b/sc/source/core/data/drwlayer.cxx
index c537eae5fdce..781097d0424c 100644
--- a/sc/source/core/data/drwlayer.cxx
+++ b/sc/source/core/data/drwlayer.cxx
@@ -450,7 +450,7 @@ void ScDrawLayer::ScCopyPage( sal_uInt16 nOldPos, sal_uInt16 nNewPos )
SCTAB nOldTab = static_cast<SCTAB>(nOldPos);
SCTAB nNewTab = static_cast<SCTAB>(nNewPos);
- SdrObjListIter aIter( *pOldPage, IM_FLAT );
+ SdrObjListIter aIter( *pOldPage, SdrIterMode::Flat );
SdrObject* pOldObject = aIter.Next();
while (pOldObject)
{
@@ -505,7 +505,7 @@ void ScDrawLayer::ResetTab( SCTAB nStart, SCTAB nEnd )
if (!pPage)
continue;
- SdrObjListIter aIter(*pPage, IM_FLAT);
+ SdrObjListIter aIter(*pPage, SdrIterMode::Flat);
for (SdrObject* pObj = aIter.Next(); pObj; pObj = aIter.Next())
{
ScDrawObjData* pData = GetObjData(pObj);
@@ -1019,7 +1019,7 @@ bool ScDrawLayer::GetPrintArea( ScRange& rRange, bool bSetHor, bool bSetVer ) co
OSL_ENSURE(pPage,"Page not found");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1258,7 +1258,7 @@ void ScDrawLayer::DeleteObjectsInArea( SCTAB nTab, SCCOL nCol1,SCROW nRow1,
std::unique_ptr<SdrObject*[]> ppObj(new SdrObject*[nObjCount]);
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1315,7 +1315,7 @@ void ScDrawLayer::DeleteObjectsInSelection( const ScMarkData& rMark )
std::unique_ptr<SdrObject*[]> ppObj(new SdrObject*[nObjCount]);
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1362,7 +1362,7 @@ void ScDrawLayer::CopyToClip( ScDocument* pClipDoc, SCTAB nTab, const Rectangle&
ScDrawLayer* pDestModel = nullptr;
SdrPage* pDestPage = nullptr;
- SdrObjListIter aIter( *pSrcPage, IM_FLAT );
+ SdrObjListIter aIter( *pSrcPage, SdrIterMode::Flat );
SdrObject* pOldObject = aIter.Next();
while (pOldObject)
{
@@ -1488,7 +1488,7 @@ void ScDrawLayer::CopyFromClip( ScDrawLayer* pClipModel, SCTAB nSourceTab, const
if ( !pSrcPage || !pDestPage )
return;
- SdrObjListIter aIter( *pSrcPage, IM_FLAT );
+ SdrObjListIter aIter( *pSrcPage, SdrIterMode::Flat );
SdrObject* pOldObject = aIter.Next();
ScDocument* pClipDoc = pClipModel->GetDocument();
@@ -1776,7 +1776,7 @@ SdrObject* ScDrawLayer::GetNamedObject( const OUString& rName, sal_uInt16 nId, S
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1829,7 +1829,7 @@ void ScDrawLayer::EnsureGraphicNames()
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
/* The index passed to GetNewGraphicName() will be set to
diff --git a/sc/source/core/tool/charthelper.cxx b/sc/source/core/tool/charthelper.cxx
index e75677cb50a5..ee93d8400576 100644
--- a/sc/source/core/tool/charthelper.cxx
+++ b/sc/source/core/tool/charthelper.cxx
@@ -52,7 +52,7 @@ sal_uInt16 lcl_DoUpdateCharts( const ScAddress& rPos, ScDocument* pDoc, bool bAl
SdrPage* pPage = pModel->GetPage(nPageNo);
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -130,7 +130,7 @@ void ScChartHelper::AdjustRangesOfChartsOnDestinationPage( ScDocument* pSrcDoc,
SdrPage* pDestPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nDestTab));
if( pDestPage )
{
- SdrObjListIter aIter( *pDestPage, IM_FLAT );
+ SdrObjListIter aIter( *pDestPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while( pObject )
{
@@ -170,7 +170,7 @@ void ScChartHelper::UpdateChartsOnDestinationPage( ScDocument* pDestDoc, const S
SdrPage* pDestPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nDestTab));
if( pDestPage )
{
- SdrObjListIter aIter( *pDestPage, IM_FLAT );
+ SdrObjListIter aIter( *pDestPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while( pObject )
{
@@ -345,7 +345,7 @@ void ScChartHelper::FillProtectedChartRangesVector( ScRangeListVector& rRangesVe
{
if ( pDocument && pPage )
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while ( pObject )
{
@@ -359,7 +359,7 @@ void ScChartHelper::GetChartNames( ::std::vector< OUString >& rChartNames, SdrPa
{
if ( pPage )
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while ( pObject )
{
@@ -383,7 +383,7 @@ void ScChartHelper::CreateProtectedChartListenersAndNotify( ScDocument* pDoc, Sd
{
size_t nRangeListCount = rRangesVector.size();
size_t nRangeList = 0;
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while ( pObject )
{
diff --git a/sc/source/core/tool/chartlock.cxx b/sc/source/core/tool/chartlock.cxx
index 98352fe96751..985774b952e9 100644
--- a/sc/source/core/tool/chartlock.cxx
+++ b/sc/source/core/tool/chartlock.cxx
@@ -53,7 +53,7 @@ std::vector< WeakReference< frame::XModel > > lcl_getAllLivingCharts( ScDocument
SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/core/tool/detfunc.cxx b/sc/source/core/tool/detfunc.cxx
index b4d05d047239..9e3a2c94833c 100644
--- a/sc/source/core/tool/detfunc.cxx
+++ b/sc/source/core/tool/detfunc.cxx
@@ -406,7 +406,7 @@ bool ScDetectiveFunc::HasArrow( const ScAddress& rStart,
OSL_ENSURE(pPage,"Page ?");
bool bFound = false;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
@@ -674,7 +674,7 @@ void ScDetectiveFunc::DeleteArrowsAt( SCCOL nCol, SCROW nRow, bool bDestPnt )
size_t nDelCount = 0;
std::unique_ptr<SdrObject*[]> ppObj(new SdrObject*[nObjCount]);
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -747,7 +747,7 @@ void ScDetectiveFunc::DeleteBox( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nR
size_t nDelCount = 0;
std::unique_ptr<SdrObject*[]> ppObj(new SdrObject*[nObjCount]);
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1249,7 +1249,7 @@ bool ScDetectiveFunc::DeleteAll( ScDetectiveDelete eWhat )
{
std::unique_ptr<SdrObject*[]> ppObj(new SdrObject*[nObjCount]);
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -1424,7 +1424,7 @@ void ScDetectiveFunc::UpdateAllComments( ScDocument& rDoc )
OSL_ENSURE( pPage, "Page ?" );
if( pPage )
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
for( SdrObject* pObject = aIter.Next(); pObject; pObject = aIter.Next() )
{
if ( ScDrawObjData* pData = ScDrawLayer::GetNoteCaptionData( pObject, nObjTab ) )
@@ -1465,7 +1465,7 @@ void ScDetectiveFunc::UpdateAllArrowColors()
OSL_ENSURE( pPage, "Page ?" );
if( pPage )
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
for( SdrObject* pObject = aIter.Next(); pObject; pObject = aIter.Next() )
{
if ( pObject->GetLayer() == SC_LAYER_INTERN )
diff --git a/sc/source/filter/excel/xiescher.cxx b/sc/source/filter/excel/xiescher.cxx
index 4df47f1a8042..8328378c7e36 100644
--- a/sc/source/filter/excel/xiescher.cxx
+++ b/sc/source/filter/excel/xiescher.cxx
@@ -3170,7 +3170,7 @@ void XclImpSolverContainer::RemoveSdrObjectInfo( SdrObject& rSdrObj )
if( SdrObjList* pSubList = pGroupObj->GetSubList() )
{
// iterate flat over the list because this function already works recursively
- SdrObjListIter aObjIt( *pSubList, IM_FLAT );
+ SdrObjListIter aObjIt( *pSubList, SdrIterMode::Flat );
for( SdrObject* pChildObj = aObjIt.Next(); pChildObj; pChildObj = aObjIt.Next() )
RemoveSdrObjectInfo( *pChildObj );
}
diff --git a/sc/source/filter/html/htmlexp2.cxx b/sc/source/filter/html/htmlexp2.cxx
index 9c2113ecfd1c..d61cadaa2eae 100644
--- a/sc/source/filter/html/htmlexp2.cxx
+++ b/sc/source/filter/html/htmlexp2.cxx
@@ -72,7 +72,7 @@ void ScHTMLExport::FillGraphList( const SdrPage* pPage, SCTAB nTab,
Rectangle aRect;
if ( !bAll )
aRect = pDoc->GetMMRect( nStartCol, nStartRow, nEndCol, nEndRow, nTab );
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while ( pObject )
{
diff --git a/sc/source/ui/app/client.cxx b/sc/source/ui/app/client.cxx
index a762755cd8c3..e8deabcc36f0 100644
--- a/sc/source/ui/app/client.cxx
+++ b/sc/source/ui/app/client.cxx
@@ -61,7 +61,7 @@ SdrOle2Obj* ScClient::GetDrawObj()
for (sal_uInt16 nPNr=0; nPNr<nPages && !pOle2Obj; nPNr++)
{
SdrPage* pPage = pModel->GetPage(nPNr);
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !pOle2Obj)
{
diff --git a/sc/source/ui/app/drwtrans.cxx b/sc/source/ui/app/drwtrans.cxx
index b6c1487d021f..69e21d8e4e49 100644
--- a/sc/source/ui/app/drwtrans.cxx
+++ b/sc/source/ui/app/drwtrans.cxx
@@ -94,7 +94,7 @@ ScDrawTransferObj::ScDrawTransferObj( SdrModel* pClipModel, ScDocShell* pContain
SdrPage* pPage = pModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
if (pObject && !aIter.Next()) // exactly one object?
{
@@ -260,7 +260,7 @@ static bool lcl_HasOnlyControls( SdrModel* pModel )
SdrPage* pPage = pModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObj = aIter.Next();
if ( pObj )
{
@@ -411,7 +411,7 @@ bool ScDrawTransferObj::GetData( const css::datatransfer::DataFlavor& rFlavor, c
SdrPage* pPage = pModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
if (pObject && pObject->GetObjIdentifier() == OBJ_GRAF)
{
@@ -471,7 +471,7 @@ bool ScDrawTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, voi
for(sal_uInt16 a(0); a < pModel->GetPageCount(); a++)
{
const SdrPage* pPage = pModel->GetPage(a);
- SdrObjListIter aIter(*pPage, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pPage, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -680,7 +680,7 @@ SdrOle2Obj* ScDrawTransferObj::GetSingleObject()
SdrPage* pPage = pModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
if (pObject && pObject->GetObjIdentifier() == OBJ_OLE2)
{
@@ -740,7 +740,7 @@ void ScDrawTransferObj::InitDocShell()
SdrPage* pPage = pDestModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/drawfunc/fupoor.cxx b/sc/source/ui/drawfunc/fupoor.cxx
index f0b86395cc9f..73965e639051 100644
--- a/sc/source/ui/drawfunc/fupoor.cxx
+++ b/sc/source/ui/drawfunc/fupoor.cxx
@@ -224,7 +224,7 @@ bool FuPoor::IsDetectiveHit( const Point& rLogicPos )
return false;
bool bFound = false;
- SdrObjListIter aIter( *pPV->GetObjList(), IM_FLAT );
+ SdrObjListIter aIter( *pPV->GetObjList(), SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
diff --git a/sc/source/ui/drawfunc/fusel2.cxx b/sc/source/ui/drawfunc/fusel2.cxx
index 6894c81cd528..61ba449bb906 100644
--- a/sc/source/ui/drawfunc/fusel2.cxx
+++ b/sc/source/ui/drawfunc/fusel2.cxx
@@ -52,7 +52,7 @@ bool FuSelection::TestDetective( SdrPageView* pPV, const Point& rPos )
return false;
bool bFound = false;
- SdrObjListIter aIter( *pPV->GetObjList(), IM_FLAT );
+ SdrObjListIter aIter( *pPV->GetObjList(), SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
@@ -131,7 +131,7 @@ bool FuSelection::IsNoteCaptionClicked( const Point& rPos ) const
bool bProtectDoc = rDoc.IsTabProtected( nTab ) || (pDocSh && pDocSh->IsReadOnly());
// search the last object (on top) in the object list
- SdrObjListIter aIter( *pPageView->GetObjList(), IM_DEEPNOGROUPS, true );
+ SdrObjListIter aIter( *pPageView->GetObjList(), SdrIterMode::DeepNoGroups, true );
for( SdrObject* pObj = aIter.Next(); pObj; pObj = aIter.Next() )
{
if( pObj->GetLogicRect().IsInside( rPos ) )
diff --git a/sc/source/ui/navipi/content.cxx b/sc/source/ui/navipi/content.cxx
index 44de2427dd94..8b6768cee6e0 100644
--- a/sc/source/ui/navipi/content.cxx
+++ b/sc/source/ui/navipi/content.cxx
@@ -164,7 +164,7 @@ OUString ScContentTree::getAltLongDescText( SvTreeListEntry* pEntry, bool isAltT
{
SdrObject* pFound = nullptr;
ScDocument* pDoc = ( const_cast< ScContentTree* >(this) )->GetSourceDocument();
- SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? IM_FLAT : IM_DEEPNOGROUPS;
+ SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? SdrIterMode::Flat : SdrIterMode::DeepNoGroups;
ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
SfxObjectShell* pShell = pDoc->GetDocumentShell();
if (pDrawLayer && pShell)
@@ -933,7 +933,7 @@ void ScContentTree::GetDrawNames( ScContentId nType )
return;
// iterate in flat mode for groups
- SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? IM_FLAT : IM_DEEPNOGROUPS;
+ SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? SdrIterMode::Flat : SdrIterMode::DeepNoGroups;
ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
SfxObjectShell* pShell = pDoc->GetDocumentShell();
@@ -1140,7 +1140,7 @@ bool ScContentTree::DrawNamesChanged( ScContentId nType )
SvTreeListEntry* pEntry = FirstChild( pParent );
// iterate in flat mode for groups
- SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? IM_FLAT : IM_DEEPNOGROUPS;
+ SdrIterMode eIter = ( nType == ScContentId::DRAWING ) ? SdrIterMode::Flat : SdrIterMode::DeepNoGroups;
bool bEqual = true;
ScDrawLayer* pDrawLayer = pDoc->GetDrawLayer();
diff --git a/sc/source/ui/uitest/uiobject.cxx b/sc/source/ui/uitest/uiobject.cxx
index 8e2044baec9f..9fcf21861f62 100644
--- a/sc/source/ui/uitest/uiobject.cxx
+++ b/sc/source/ui/uitest/uiobject.cxx
@@ -196,7 +196,7 @@ std::set<OUString> collect_charts(VclPtr<ScGridWindow> const & xGridWindow)
if (!pPage)
return aRet;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/undo/undotab.cxx b/sc/source/ui/undo/undotab.cxx
index 351842ae20b1..4470fc1231fc 100644
--- a/sc/source/ui/undo/undotab.cxx
+++ b/sc/source/ui/undo/undotab.cxx
@@ -1462,7 +1462,7 @@ SdrObject* ScUndoRenameObject::GetObject()
SdrPage* pPage = pDrawLayer->GetPage(nTab);
assert(pPage && "Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/unoobj/chartuno.cxx b/sc/source/ui/unoobj/chartuno.cxx
index b974560f7a9b..311353a1d3c1 100644
--- a/sc/source/ui/unoobj/chartuno.cxx
+++ b/sc/source/ui/unoobj/chartuno.cxx
@@ -66,7 +66,7 @@ static SdrOle2Obj* lcl_FindChartObj( ScDocShell* pDocShell, SCTAB nTab, const OU
OSL_ENSURE(pPage, "Page nicht gefunden");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -128,7 +128,7 @@ ScChartObj* ScChartsObj::GetObjectByIndex_Impl(long nIndex) const
if (pPage)
{
long nPos = 0;
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -340,7 +340,7 @@ sal_Int32 SAL_CALL ScChartsObj::getCount() throw(uno::RuntimeException, std::exc
OSL_ENSURE(pPage, "Page nicht gefunden");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -409,7 +409,7 @@ uno::Sequence<OUString> SAL_CALL ScChartsObj::getElementNames() throw(uno::Runti
OSL_ENSURE(pPage, "Page nicht gefunden");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/unoobj/docuno.cxx b/sc/source/ui/unoobj/docuno.cxx
index 442ad4c8da20..57c83e9999be 100644
--- a/sc/source/ui/unoobj/docuno.cxx
+++ b/sc/source/ui/unoobj/docuno.cxx
@@ -1229,7 +1229,7 @@ static bool lcl_ParseTarget( const OUString& rTarget, ScRange& rTargetRange, Rec
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !bRangeValid)
{
diff --git a/sc/source/ui/unoobj/viewuno.cxx b/sc/source/ui/unoobj/viewuno.cxx
index f9081072beaf..a1cf8d282bdb 100644
--- a/sc/source/ui/unoobj/viewuno.cxx
+++ b/sc/source/ui/unoobj/viewuno.cxx
@@ -655,7 +655,7 @@ static void lcl_ShowObject( ScTabViewShell& rViewSh, ScDrawView& rDrawView, SdrO
SdrPage* pPage = pModel->GetPage(i);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !bFound)
{
diff --git a/sc/source/ui/view/dbfunc4.cxx b/sc/source/ui/view/dbfunc4.cxx
index 7c9f27987bbb..cae85ae9ad83 100644
--- a/sc/source/ui/view/dbfunc4.cxx
+++ b/sc/source/ui/view/dbfunc4.cxx
@@ -41,7 +41,7 @@ sal_uInt16 ScDBFunc::DoUpdateCharts( const ScAddress& rPos, ScDocument* pDoc, bo
SdrPage* pPage = pModel->GetPage(nPageNo);
OSL_ENSURE(pPage,"Page ?");
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/view/drawvie4.cxx b/sc/source/ui/view/drawvie4.cxx
index cbbc3af03f1c..0fafd4d34b2a 100644
--- a/sc/source/ui/view/drawvie4.cxx
+++ b/sc/source/ui/view/drawvie4.cxx
@@ -70,7 +70,7 @@ void ScDrawView::CheckOle( const SdrMarkList& rMarkList, bool& rAnyOle, bool& rO
}
else if ( dynamic_cast<const SdrObjGroup*>( pObj) != nullptr )
{
- SdrObjListIter aIter( *pObj, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pObj, SdrIterMode::DeepNoGroups );
SdrObject* pSubObj = aIter.Next();
while (pSubObj)
{
@@ -251,7 +251,7 @@ void getChartSourceRanges(ScDocument* pDoc, const SdrMarkList& rObjs, std::vecto
break;
case OBJ_GRUP:
{
- SdrObjListIter aIter(*pObj, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepNoGroups);
for (SdrObject* pSubObj = aIter.Next(); pSubObj; pSubObj = aIter.Next())
{
if (pSubObj->GetObjIdentifier() != OBJ_OLE2)
diff --git a/sc/source/ui/view/drawview.cxx b/sc/source/ui/view/drawview.cxx
index 76b6c2783eae..4003cd86a695 100644
--- a/sc/source/ui/view/drawview.cxx
+++ b/sc/source/ui/view/drawview.cxx
@@ -656,7 +656,7 @@ SdrObject* ScDrawView::GetObjectByName(const OUString& rName)
DBG_ASSERT(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
@@ -690,7 +690,7 @@ void ScDrawView::SelectCurrentViewObject( const OUString& rName )
DBG_ASSERT(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !pFound)
{
@@ -744,7 +744,7 @@ bool ScDrawView::SelectObject( const OUString& rName )
OSL_ENSURE(pPage,"Page ?");
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject && !pFound)
{
diff --git a/sc/source/ui/view/tabvwshb.cxx b/sc/source/ui/view/tabvwshb.cxx
index ec7ce83e3c72..d25958848db5 100644
--- a/sc/source/ui/view/tabvwshb.cxx
+++ b/sc/source/ui/view/tabvwshb.cxx
@@ -400,7 +400,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
pNewDBField->NbcSetLayer(SC_LAYER_FRONT);
if (dynamic_cast<const SdrObjGroup*>( pNewDBField) != nullptr)
{
- SdrObjListIter aIter( *pNewDBField, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pNewDBField, SdrIterMode::DeepWithGroups );
SdrObject* pSubObj = aIter.Next();
while (pSubObj)
{
diff --git a/sc/source/ui/view/viewfun5.cxx b/sc/source/ui/view/viewfun5.cxx
index 4d983797914b..56684efc5055 100644
--- a/sc/source/ui/view/viewfun5.cxx
+++ b/sc/source/ui/view/viewfun5.cxx
@@ -438,7 +438,7 @@ bool ScViewFunc::PasteDataFormat( SotClipboardFormatId nFormatId,
pObj->NbcSetLayer(SC_LAYER_FRONT);
if (dynamic_cast<const SdrObjGroup*>( pObj) != nullptr)
{
- SdrObjListIter aIter( *pObj, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pObj, SdrIterMode::DeepWithGroups );
SdrObject* pSubObj = aIter.Next();
while (pSubObj)
{
@@ -505,7 +505,7 @@ bool ScViewFunc::PasteDataFormat( SotClipboardFormatId nFormatId,
for (sal_uInt16 i=0; i<nPages; i++)
{
SdrPage* pPage = pModel->GetPage(i);
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sc/source/ui/view/viewfun7.cxx b/sc/source/ui/view/viewfun7.cxx
index da2bdba0d113..5e769f87c7bd 100644
--- a/sc/source/ui/view/viewfun7.cxx
+++ b/sc/source/ui/view/viewfun7.cxx
@@ -232,7 +232,7 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
// controls must be on SC_LAYER_CONTROLS
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObject = aIter.Next();
while (pObject)
{
diff --git a/sd/source/core/CustomAnimationCloner.cxx b/sd/source/core/CustomAnimationCloner.cxx
index b43172ad5804..6fcb46e5fb32 100644
--- a/sd/source/core/CustomAnimationCloner.cxx
+++ b/sd/source/core/CustomAnimationCloner.cxx
@@ -96,8 +96,8 @@ namespace sd
// create a dictionary to map source to cloned shapes
if( pSourcePage && pTargetPage )
{
- SdrObjListIter aSourceIter( *pSourcePage, IM_DEEPWITHGROUPS );
- SdrObjListIter aTargetIter( *pTargetPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aSourceIter( *pSourcePage, SdrIterMode::DeepWithGroups );
+ SdrObjListIter aTargetIter( *pTargetPage, SdrIterMode::DeepWithGroups );
while( aSourceIter.IsMore() && aTargetIter.IsMore() )
{
diff --git a/sd/source/core/drawdoc2.cxx b/sd/source/core/drawdoc2.cxx
index d65ddc76ae92..9e3672570e21 100644
--- a/sd/source/core/drawdoc2.cxx
+++ b/sd/source/core/drawdoc2.cxx
@@ -92,7 +92,7 @@ SdrObject* SdDrawDocument::GetObj(const OUString& rObjName) const
while (nPage < nMaxPages && !pObjFound)
{
pPage = static_cast<const SdPage*>( GetPage(nPage) );
- SdrObjListIter aIter(*pPage, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pPage, SdrIterMode::DeepWithGroups);
while (aIter.IsMore() && !pObjFound)
{
@@ -117,7 +117,7 @@ SdrObject* SdDrawDocument::GetObj(const OUString& rObjName) const
while (nPage < nMaxMasterPages && !pObjFound)
{
pPage = static_cast<const SdPage*>( GetMasterPage(nPage) );
- SdrObjListIter aIter(*pPage, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pPage, SdrIterMode::DeepWithGroups);
while (aIter.IsMore() && !pObjFound)
{
diff --git a/sd/source/core/drawdoc4.cxx b/sd/source/core/drawdoc4.cxx
index ed0c55bdf306..046bb138a4b3 100644
--- a/sd/source/core/drawdoc4.cxx
+++ b/sd/source/core/drawdoc4.cxx
@@ -781,7 +781,7 @@ void SdDrawDocument::StartOnlineSpelling(bool bForceSpelling)
// Fill OnlineSpelling list
void SdDrawDocument::FillOnlineSpellingList(SdPage* pPage)
{
- SdrObjListIter aIter(*pPage, IM_FLAT);
+ SdrObjListIter aIter(*pPage, SdrIterMode::Flat);
while (aIter.IsMore())
{
@@ -799,7 +799,7 @@ void SdDrawDocument::FillOnlineSpellingList(SdPage* pPage)
{
// Found a group object
SdrObjListIter aGroupIter(*static_cast<SdrObjGroup*>(pObj)->GetSubList(),
- IM_DEEPNOGROUPS);
+ SdrIterMode::DeepNoGroups);
bool bSubTextObjFound = false;
@@ -840,7 +840,7 @@ IMPL_LINK_NOARG_TYPED(SdDrawDocument, OnlineSpellingHdl, Idle *, void)
{
// Found a group object
SdrObjListIter aGroupIter(*static_cast<SdrObjGroup*>(pObj)->GetSubList(),
- IM_DEEPNOGROUPS);
+ SdrIterMode::DeepNoGroups);
while (aGroupIter.IsMore())
diff --git a/sd/source/core/sdpage2.cxx b/sd/source/core/sdpage2.cxx
index f3ca063dc0b7..bbb6598c5d9d 100644
--- a/sd/source/core/sdpage2.cxx
+++ b/sd/source/core/sdpage2.cxx
@@ -442,8 +442,8 @@ SdrPage* SdPage::Clone(SdrModel* pNewModel) const
cloneAnimations( *pNewPage );
// fix user calls for duplicated slide
- SdrObjListIter aSourceIter( *this, IM_DEEPWITHGROUPS );
- SdrObjListIter aTargetIter( *pNewPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aSourceIter( *this, SdrIterMode::DeepWithGroups );
+ SdrObjListIter aTargetIter( *pNewPage, SdrIterMode::DeepWithGroups );
while( aSourceIter.IsMore() && aTargetIter.IsMore() )
{
@@ -513,7 +513,7 @@ void SdPage::getAlienAttributes( css::uno::Any& rAttributes )
void SdPage::RemoveEmptyPresentationObjects()
{
- SdrObjListIter aShapeIter( *this, IM_DEEPWITHGROUPS );
+ SdrObjListIter aShapeIter( *this, SdrIterMode::DeepWithGroups );
SdrObject* pShape;
for( pShape = aShapeIter.Next(); pShape; pShape = aShapeIter.Next() )
diff --git a/sd/source/filter/html/htmlex.cxx b/sd/source/filter/html/htmlex.cxx
index c5f39da0be1e..0fe824e86a8f 100644
--- a/sd/source/filter/html/htmlex.cxx
+++ b/sd/source/filter/html/htmlex.cxx
@@ -1295,7 +1295,7 @@ void HtmlExport::WriteTable(OUStringBuffer& aStr, SdrTableObj* pTableObject, Sdr
void HtmlExport::WriteObjectGroup(OUStringBuffer& aStr, SdrObjGroup* pObjectGroup, SdrOutliner* pOutliner,
const Color& rBackgroundColor, bool bHeadLine)
{
- SdrObjListIter aGroupIterator(*pObjectGroup->GetSubList(), IM_DEEPNOGROUPS);
+ SdrObjListIter aGroupIterator(*pObjectGroup->GetSubList(), SdrIterMode::DeepNoGroups);
while (aGroupIterator.IsMore())
{
SdrObject* pCurrentObject = aGroupIterator.Next();
@@ -1562,7 +1562,7 @@ bool HtmlExport::CreateHtmlForPresPages()
while (!bMasterDone)
{
// sal_True = backwards
- SdrObjListIter aIter(*pPage, IM_DEEPWITHGROUPS, true);
+ SdrObjListIter aIter(*pPage, SdrIterMode::DeepWithGroups, true);
SdrObject* pObject = aIter.Next();
while (pObject)
diff --git a/sd/source/filter/ppt/pptin.cxx b/sd/source/filter/ppt/pptin.cxx
index 0c537ed3755f..ce1b85f36bfa 100644
--- a/sd/source/filter/ppt/pptin.cxx
+++ b/sd/source/filter/ppt/pptin.cxx
@@ -1845,7 +1845,7 @@ void ImplSdPPTImport::ImportPageEffect( SdPage* pPage, const bool bNewAnimations
tAnimationVector aAnimationsOnThisPage;
// add effects from page in correct order
- SdrObjListIter aSdrIter( *pPage, IM_FLAT );
+ SdrObjListIter aSdrIter( *pPage, SdrIterMode::Flat );
while ( aSdrIter.IsMore() )
{
SdrObject* pObj = aSdrIter.Next();
diff --git a/sd/source/ui/app/sdxfer.cxx b/sd/source/ui/app/sdxfer.cxx
index 6f07464ae178..cdf627953bfe 100644
--- a/sd/source/ui/app/sdxfer.cxx
+++ b/sd/source/ui/app/sdxfer.cxx
@@ -354,7 +354,7 @@ static bool lcl_HasOnlyControls( SdrModel* pModel )
SdrPage* pPage = pModel->GetPage(0);
if (pPage)
{
- SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
SdrObject* pObj = aIter.Next();
if ( pObj )
{
diff --git a/sd/source/ui/dlg/sdtreelb.cxx b/sd/source/ui/dlg/sdtreelb.cxx
index acf5f690a45e..0f6303506eb5 100644
--- a/sd/source/ui/dlg/sdtreelb.cxx
+++ b/sd/source/ui/dlg/sdtreelb.cxx
@@ -285,7 +285,7 @@ OUString SdPageObjsTLB::getAltLongDescText(SvTreeListEntry* pEntry , bool isAltT
const SdPage* pPage = static_cast<const SdPage*>( mpDoc->GetPage( pageNo ) );
if( pPage->GetPageKind() != PK_STANDARD ) continue;
if( pPage->GetName() != ParentName ) continue;
- SdrObjListIter aIter( *pPage, IM_FLAT );
+ SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
while( aIter.IsMore() )
{
pObj = aIter.Next();
@@ -600,7 +600,7 @@ void SdPageObjsTLB::AddShapeList (
SdrObjListIter aIter(
rList,
!rList.HasObjectNavigationOrder() /* use navigation order, if available */,
- IM_FLAT);
+ SdrIterMode::Flat);
bool bMarked=false;
if(bisInSdNavigatorWin)
@@ -838,7 +838,7 @@ bool SdPageObjsTLB::IsEqualToDoc( const SdDrawDocument* pInDoc )
SdrObjListIter aIter(
*pPage,
!pPage->HasObjectNavigationOrder() /* use navigation order, if available */,
- IM_DEEPWITHGROUPS );
+ SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
@@ -928,7 +928,7 @@ void SdPageObjsTLB::RequestingChildren( SvTreeListEntry* pFileEntry )
TREELIST_APPEND,
reinterpret_cast< void* >( 1 ) );
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
diff --git a/sd/source/ui/func/fupoor.cxx b/sd/source/ui/func/fupoor.cxx
index 52fa9a7f747a..7af92eac1334 100644
--- a/sd/source/ui/func/fupoor.cxx
+++ b/sd/source/ui/func/fupoor.cxx
@@ -209,7 +209,7 @@ bool FuPoor::KeyInput(const KeyEvent& rKEvt)
if(pActualPage)
{
- SdrObjListIter aIter(*pActualPage, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pActualPage, SdrIterMode::DeepNoGroups);
while(aIter.IsMore() && !pCandidate)
{
@@ -841,7 +841,7 @@ bool FuPoor::KeyInput(const KeyEvent& rKEvt)
if(pActualPage)
{
- SdrObjListIter aIter(*pActualPage, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pActualPage, SdrIterMode::DeepNoGroups);
while(aIter.IsMore() && !pCandidate)
{
diff --git a/sd/source/ui/unoidl/unopage.cxx b/sd/source/ui/unoidl/unopage.cxx
index 668325ae0add..11269c1dec0b 100644
--- a/sd/source/ui/unoidl/unopage.cxx
+++ b/sd/source/ui/unoidl/unopage.cxx
@@ -1933,7 +1933,7 @@ sal_Bool SAL_CALL SdPageLinkTargets::hasElements()
SdPage* pPage = mpUnoPage->GetPage();
if( pPage != nullptr )
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
@@ -1981,7 +1981,7 @@ Sequence< OUString > SAL_CALL SdPageLinkTargets::getElementNames()
SdPage* pPage = mpUnoPage->GetPage();
if( pPage != nullptr )
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pObj = aIter.Next();
@@ -1998,7 +1998,7 @@ Sequence< OUString > SAL_CALL SdPageLinkTargets::getElementNames()
{
OUString* pStr = aSeq.getArray();
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pObj = aIter.Next();
@@ -2027,7 +2027,7 @@ SdrObject* SdPageLinkTargets::FindObject( const OUString& rName ) const throw()
if( pPage == nullptr )
return nullptr;
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
diff --git a/sd/source/ui/view/OutlinerIterator.cxx b/sd/source/ui/view/OutlinerIterator.cxx
index 8a2188b46673..1eb3351f8a4d 100644
--- a/sd/source/ui/view/OutlinerIterator.cxx
+++ b/sd/source/ui/view/OutlinerIterator.cxx
@@ -575,7 +575,7 @@ IteratorImplBase* ViewIteratorImpl::Clone (IteratorImplBase* pObject) const
if (mpObjectIterator != nullptr)
{
- pIterator->mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, !mbDirectionIsForward);
+ pIterator->mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, !mbDirectionIsForward);
// No direct way to set the object iterator to the current object.
pIterator->maPosition.mxObject.reset(nullptr);
@@ -620,7 +620,7 @@ void ViewIteratorImpl::GotoNextText()
SetPage (maPosition.mnPageIndex-1);
if (mpPage != nullptr)
- mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, !mbDirectionIsForward);
+ mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, !mbDirectionIsForward);
if (mpObjectIterator!=nullptr && mpObjectIterator->IsMore())
maPosition.mxObject.reset(mpObjectIterator->Next());
else
@@ -672,7 +672,7 @@ void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
// Set up object list iterator.
if (mpPage != nullptr)
- mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, ! mbDirectionIsForward);
+ mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, ! mbDirectionIsForward);
else
mpObjectIterator = nullptr;
@@ -700,7 +700,7 @@ void ViewIteratorImpl::Reverse()
if (mpObjectIterator != nullptr)
delete mpObjectIterator;
if (mpPage != nullptr)
- mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, ! mbDirectionIsForward);
+ mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, ! mbDirectionIsForward);
else
mpObjectIterator = nullptr;
diff --git a/sd/source/ui/view/drviews4.cxx b/sd/source/ui/view/drviews4.cxx
index c390ffaf244e..dc4091eefa62 100644
--- a/sd/source/ui/view/drviews4.cxx
+++ b/sd/source/ui/view/drviews4.cxx
@@ -147,7 +147,7 @@ bool DrawViewShell::KeyInput (const KeyEvent& rKEvt, ::sd::Window* pWin)
GetView()->SdrEndTextEdit();
// look for a new candidate, a successor of pOldObj
- SdrObjListIter aIter(*pActualPage, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pActualPage, SdrIterMode::DeepNoGroups);
bool bDidVisitOldObject(false);
while(aIter.IsMore() && !pCandidate)
diff --git a/svx/source/customshapes/EnhancedCustomShape3d.cxx b/svx/source/customshapes/EnhancedCustomShape3d.cxx
index 10c372d7e48d..94e8eff10db8 100644
--- a/svx/source/customshapes/EnhancedCustomShape3d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape3d.cxx
@@ -368,7 +368,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
}
Rectangle aBoundRect2d;
- SdrObjListIter aIter( *pShape2d, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pShape2d, SdrIterMode::DeepNoGroups );
const bool bMultipleSubObjects(aIter.Count() > 1);
while( aIter.IsMore() )
diff --git a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
index 692e08ec1ce9..15ce39efb7d7 100644
--- a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
@@ -433,7 +433,7 @@ drawing::PolyPolygonBezierCoords SAL_CALL EnhancedCustomShapeEngine::getLineGeom
}
basegfx::B2DPolyPolygon aPolyPolygon;
- SdrObjListIter aIter( *pObj, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pObj, SdrIterMode::DeepWithGroups );
while ( aIter.IsMore() )
{
diff --git a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
index 89f1d6f2413a..989d329cdd7e 100644
--- a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
@@ -510,7 +510,7 @@ basegfx::B2DPolyPolygon GetOutlinesFromShape2d( const SdrObject* pShape2d )
{
basegfx::B2DPolyPolygon aOutlines2d;
- SdrObjListIter aObjListIter( *pShape2d, IM_DEEPWITHGROUPS );
+ SdrObjListIter aObjListIter( *pShape2d, SdrIterMode::DeepWithGroups );
while( aObjListIter.IsMore() )
{
SdrObject* pPartObj = aObjListIter.Next();
diff --git a/svx/source/engine3d/helperhittest3d.cxx b/svx/source/engine3d/helperhittest3d.cxx
index c9b47b3394d2..eb0226981d07 100644
--- a/svx/source/engine3d/helperhittest3d.cxx
+++ b/svx/source/engine3d/helperhittest3d.cxx
@@ -175,7 +175,7 @@ void getAllHit3DObjectsSortedFrontToBack(
// check if test point is inside scene's area at all
if(aRelativePoint.getX() >= 0.0 && aRelativePoint.getX() <= 1.0 && aRelativePoint.getY() >= 0.0 && aRelativePoint.getY() <= 1.0)
{
- SdrObjListIter aIterator(*pList, IM_DEEPNOGROUPS);
+ SdrObjListIter aIterator(*pList, SdrIterMode::DeepNoGroups);
::std::vector< ImplPairDephAndObject > aDepthAndObjectResults;
const uno::Sequence< beans::PropertyValue > aEmptyParameters;
drawinglayer::geometry::ViewInformation3D aViewInfo3D(aEmptyParameters);
diff --git a/svx/source/engine3d/scene3d.cxx b/svx/source/engine3d/scene3d.cxx
index b93ca3f01650..da2e7fb0a3d4 100644
--- a/svx/source/engine3d/scene3d.cxx
+++ b/svx/source/engine3d/scene3d.cxx
@@ -474,7 +474,7 @@ void E3dScene::RebuildLists()
// first delete
SdrLayerID nCurrLayerID = GetLayer();
- SdrObjListIter a3DIterator(maSubList, IM_FLAT);
+ SdrObjListIter a3DIterator(maSubList, SdrIterMode::Flat);
// then examine all the objects in the scene
while ( a3DIterator.IsMore() )
@@ -651,7 +651,7 @@ void E3dScene::RecalcSnapRect()
bool E3dScene::IsBreakObjPossible()
{
// Break scene, if all members are able to break
- SdrObjListIter a3DIterator(maSubList, IM_DEEPWITHGROUPS);
+ SdrObjListIter a3DIterator(maSubList, SdrIterMode::DeepWithGroups);
while ( a3DIterator.IsMore() )
{
diff --git a/svx/source/engine3d/view3d.cxx b/svx/source/engine3d/view3d.cxx
index d6e001590c73..3847c61db547 100644
--- a/svx/source/engine3d/view3d.cxx
+++ b/svx/source/engine3d/view3d.cxx
@@ -636,7 +636,7 @@ void E3dView::ImpIsConvertTo3DPossible(SdrObject* pObj, bool& rAny3D,
{
if(pObj->IsGroupObject())
{
- SdrObjListIter aIter(*pObj, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
SdrObject* pNewObj = aIter.Next();
@@ -770,7 +770,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// change text color attribute for not so dark colors
if(pObj->IsGroupObject())
{
- SdrObjListIter aIter(*pObj, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -788,7 +788,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// change text color attribute for not so dark colors
if(pNewObj1->IsGroupObject())
{
- SdrObjListIter aIter(*pNewObj1, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pNewObj1, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -806,7 +806,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// add all to flat scene
if(pNewObj2->IsGroupObject())
{
- SdrObjListIter aIter(*pNewObj2, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pNewObj2, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -1044,7 +1044,7 @@ void E3dView::DoDepthArrange(E3dScene* pScene, double fDepth)
if(pScene && pScene->GetSubList() && pScene->GetSubList()->GetObjCount() > 1)
{
SdrObjList* pSubList = pScene->GetSubList();
- SdrObjListIter aIter(*pSubList, IM_FLAT);
+ SdrObjListIter aIter(*pSubList, SdrIterMode::Flat);
E3dDepthLayer* pBaseLayer = nullptr;
E3dDepthLayer* pLayer = nullptr;
sal_Int32 nNumLayers = 0;
@@ -1585,7 +1585,7 @@ void E3dView::BreakSingle3DObj(E3dObject* pObj)
if(dynamic_cast< const E3dScene* >(pObj) != nullptr)
{
SdrObjList* pSubList = pObj->GetSubList();
- SdrObjListIter aIter(*pSubList, IM_FLAT);
+ SdrObjListIter aIter(*pSubList, SdrIterMode::Flat);
while(aIter.IsMore())
{
diff --git a/svx/source/form/fmvwimp.cxx b/svx/source/form/fmvwimp.cxx
index f330a6408451..d572c3f333a0 100644
--- a/svx/source/form/fmvwimp.cxx
+++ b/svx/source/form/fmvwimp.cxx
@@ -888,7 +888,7 @@ namespace
{
Reference< XInterface > xNormalizedForm( _rxForm, UNO_QUERY_THROW );
- SdrObjListIter aSdrObjectLoop( _rPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aSdrObjectLoop( _rPage, SdrIterMode::DeepNoGroups );
while ( aSdrObjectLoop.IsMore() )
{
FmFormObj* pFormObject = FmFormObj::GetFormObject( aSdrObjectLoop.Next() );
diff --git a/svx/source/sdr/properties/e3dsceneproperties.cxx b/svx/source/sdr/properties/e3dsceneproperties.cxx
index 44c28b5bc8b1..8c402b3f598d 100644
--- a/svx/source/sdr/properties/e3dsceneproperties.cxx
+++ b/svx/source/sdr/properties/e3dsceneproperties.cxx
@@ -286,7 +286,7 @@ namespace sdr
if(pSubList && rObj.GetScene() == &rObj)
{
- SdrObjListIter a3DIterator(*pSubList, IM_DEEPWITHGROUPS);
+ SdrObjListIter a3DIterator(*pSubList, SdrIterMode::DeepWithGroups);
while(a3DIterator.IsMore())
{
diff --git a/svx/source/sdr/properties/itemsettools.cxx b/svx/source/sdr/properties/itemsettools.cxx
index bef396c1ec41..64c70eb47307 100644
--- a/svx/source/sdr/properties/itemsettools.cxx
+++ b/svx/source/sdr/properties/itemsettools.cxx
@@ -38,7 +38,7 @@ namespace sdr
{
if(dynamic_cast<const SdrObjGroup*>( &rObj ) != nullptr)
{
- SdrObjListIter aIter(static_cast<const SdrObjGroup&>(rObj), IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(static_cast<const SdrObjGroup&>(rObj), SdrIterMode::DeepNoGroups);
mpData = new RectangleVector;
DBG_ASSERT(mpData, "ItemChangeBroadcaster: No memory (!)");
static_cast<RectangleVector*>(mpData)->reserve(aIter.Count());
diff --git a/svx/source/sdr/properties/properties.cxx b/svx/source/sdr/properties/properties.cxx
index a78aea4bcc0a..1cda9c4328d6 100644
--- a/svx/source/sdr/properties/properties.cxx
+++ b/svx/source/sdr/properties/properties.cxx
@@ -142,7 +142,7 @@ namespace sdr
// invalidate all new rectangles
if(dynamic_cast<const SdrObjGroup*>( &GetSdrObject() ) != nullptr)
{
- SdrObjListIter aIter(static_cast<SdrObjGroup&>(GetSdrObject()), IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(static_cast<SdrObjGroup&>(GetSdrObject()), SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
diff --git a/svx/source/svdraw/svdedtv1.cxx b/svx/source/svdraw/svdedtv1.cxx
index 68074a848e44..3573520eccb5 100644
--- a/svx/source/svdraw/svdedtv1.cxx
+++ b/svx/source/svdraw/svdedtv1.cxx
@@ -147,7 +147,7 @@ std::vector< SdrUndoAction* > SdrEditView::CreateConnectorUndo( SdrObject& rO )
const SdrPage* pPage = rO.GetPage();
if ( pPage )
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pPartObj = aIter.Next();
@@ -609,7 +609,7 @@ void SdrEditView::CrookMarkedObj(const Point& rRef, const Point& rRad, SdrCrookM
if (bNoContortion || pOL==nullptr) {
ImpCrookObj(pO,rRef,rRad,eMode,bVertical,bNoContortion,bRotate,aMarkRect);
} else {
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
SdrObject* pO1=aIter.Next();
ImpCrookObj(pO1,rRef,rRad,eMode,bVertical,bNoContortion,bRotate,aMarkRect);
@@ -684,7 +684,7 @@ void SdrEditView::DistortMarkedObj(const Rectangle& rRef, const XPolygon& rDisto
if (bNoContortion || pOL==nullptr) {
ImpDistortObj(pO,aRefRect,rDistortedRect,bNoContortion);
} else {
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
SdrObject* pO1=aIter.Next();
ImpDistortObj(pO1,aRefRect,rDistortedRect,bNoContortion);
diff --git a/svx/source/svdraw/svdedtv2.cxx b/svx/source/svdraw/svdedtv2.cxx
index 7cf36ae97b76..fbaf03e697a3 100644
--- a/svx/source/svdraw/svdedtv2.cxx
+++ b/svx/source/svdraw/svdedtv2.cxx
@@ -541,7 +541,7 @@ void SdrEditView::ImpCopyAttributes(const SdrObject* pSource, SdrObject* pDest)
if (pSource!=nullptr) {
SdrObjList* pOL=pSource->GetSubList();
if (pOL!=nullptr && !pSource->Is3DObj()) { // get first non-group object from group
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
pSource=aIter.Next();
}
}
@@ -588,7 +588,7 @@ bool SdrEditView::ImpCanConvertForCombine(const SdrObject* pObj)
if(pOL && !pObj->Is3DObj())
{
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -631,7 +631,7 @@ basegfx::B2DPolyPolygon SdrEditView::ImpGetPolyPolygon1(const SdrObject* pObj, b
if(pOL)
{
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -668,7 +668,7 @@ basegfx::B2DPolyPolygon SdrEditView::ImpGetPolyPolygon(const SdrObject* pObj, bo
if(pOL && !pObj->Is3DObj())
{
basegfx::B2DPolyPolygon aRetval;
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -1034,7 +1034,7 @@ void SdrEditView::MergeMarkedObjects(SdrMergeMode eMode)
// #i76891# use single iteration from SJ here which works on SdrObjects and takes
// groups into account by itself
- SdrObjListIter aIter(*pObj, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
@@ -1437,7 +1437,7 @@ bool SdrEditView::ImpCanDismantle(const SdrObject* pObj, bool bMakeLines)
if(pOL)
{
// group object -- check all members if they're PathObjs
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore() && !bOtherObjs)
{
@@ -1685,7 +1685,7 @@ void SdrEditView::DismantleMarkedObjects(bool bMakeLines)
size_t nPos=nPos0+1;
SdrObjList* pSubList=pObj->GetSubList();
if (pSubList!=nullptr && !pObj->Is3DObj()) {
- SdrObjListIter aIter(*pSubList,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pSubList,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
const SdrObject* pObj1=aIter.Next();
ImpDismantleOneObject(pObj1,*pOL,nPos,pPV,bMakeLines);
@@ -1974,7 +1974,7 @@ void SdrEditView::ImpConvertTo(bool bPath, bool bLineToArea)
SdrPageView* pPV=pM->GetPageView();
if (pObj->IsGroupObject() && !pObj->Is3DObj()) {
SdrObject* pGrp=pObj;
- SdrObjListIter aIter(*pGrp,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pGrp,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
pObj=aIter.Next();
ImpConvertOneObj(pObj,bPath,bLineToArea);
diff --git a/svx/source/svdraw/svdfmtf.cxx b/svx/source/svdraw/svdfmtf.cxx
index f1bdb80be7ef..42027a423a4f 100644
--- a/svx/source/svdraw/svdfmtf.cxx
+++ b/svx/source/svdraw/svdfmtf.cxx
@@ -510,7 +510,7 @@ void ImpSdrGDIMetaFileImport::InsertObj(SdrObject* pObj, bool bScale)
{
// recursively add created conversion; per definition this shall not
// contain further SdrTextObjs. Visit only non-group objects
- SdrObjListIter aIter(*pConverted, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pConverted, SdrIterMode::DeepNoGroups);
// work with clones; the created conversion may contain group objects
// and when working with the original objects the loop itself could
@@ -519,7 +519,7 @@ void ImpSdrGDIMetaFileImport::InsertObj(SdrObject* pObj, bool bScale)
while(aIter.IsMore())
{
SdrObject* pCandidate = aIter.Next();
- OSL_ENSURE(pCandidate && dynamic_cast< SdrObjGroup* >(pCandidate) == nullptr, "SdrObjListIter with IM_DEEPNOGROUPS error (!)");
+ OSL_ENSURE(pCandidate && dynamic_cast< SdrObjGroup* >(pCandidate) == nullptr, "SdrObjListIter with SdrIterMode::DeepNoGroups error (!)");
SdrObject* pNewClone = pCandidate->Clone();
if(pNewClone)
diff --git a/svx/source/svdraw/svditer.cxx b/svx/source/svdraw/svditer.cxx
index 3ed440278c17..a8e56773ff8c 100644
--- a/svx/source/svdraw/svditer.cxx
+++ b/svx/source/svdraw/svditer.cxx
@@ -86,10 +86,10 @@ void SdrObjListIter::ImpProcessObj(SdrObject* pObj, SdrIterMode eMode, bool bUse
if( bIsGroup && dynamic_cast<const E3dObject* >(pObj) != nullptr && dynamic_cast<const E3dScene* >(pObj) == nullptr)
bIsGroup = false;
- if( !bIsGroup || (eMode != IM_DEEPNOGROUPS) )
+ if( !bIsGroup || (eMode != SdrIterMode::DeepNoGroups) )
maObjList.push_back(pObj);
- if( bIsGroup && (eMode != IM_FLAT) )
+ if( bIsGroup && (eMode != SdrIterMode::Flat) )
ImpProcessObjectList( *pObj->GetSubList(), eMode, bUseZOrder );
}
diff --git a/svx/source/svdraw/svdpage.cxx b/svx/source/svdraw/svdpage.cxx
index 141f2f7b6fff..59def840f466 100644
--- a/svx/source/svdraw/svdpage.cxx
+++ b/svx/source/svdraw/svdpage.cxx
@@ -645,7 +645,7 @@ void SdrObjList::ReformatAllTextObjects()
void SdrObjList::ReformatAllEdgeObjects()
{
// #i120437# go over whole hierarchy, not only over object level null (seen from grouping)
- SdrObjListIter aIter(*this, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*this, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -1641,7 +1641,7 @@ void SdrPage::SetInserted( bool bIns )
mbInserted = bIns;
// #i120437# go over whole hierarchy, not only over object level null (seen from grouping)
- SdrObjListIter aIter(*this, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*this, SdrIterMode::DeepNoGroups);
while ( aIter.IsMore() )
{
diff --git a/svx/source/unodraw/unoshap3.cxx b/svx/source/unodraw/unoshap3.cxx
index fe6505d655b4..d3ab906ea951 100644
--- a/svx/source/unodraw/unoshap3.cxx
+++ b/svx/source/unodraw/unoshap3.cxx
@@ -322,7 +322,7 @@ bool Svx3DSceneObject::setPropertyValueImpl( const OUString& rName, const SfxIte
aSceneTAR.maRect = pScene->GetSnapRect();
// rescue object transformations
- SdrObjListIter aIter(*pScene->GetSubList(), IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pScene->GetSubList(), SdrIterMode::DeepWithGroups);
std::vector<basegfx::B3DHomMatrix*> aObjTrans;
while(aIter.IsMore())
{
diff --git a/sw/source/core/doc/docdraw.cxx b/sw/source/core/doc/docdraw.cxx
index 00ddcb8571c8..620996fd702c 100644
--- a/sw/source/core/doc/docdraw.cxx
+++ b/sw/source/core/doc/docdraw.cxx
@@ -603,7 +603,7 @@ namespace docfunc
{
const SdrPage& rSdrPage( *(p_rDoc.getIDocumentDrawModelAccess().GetDrawModel()->GetPage( 0 )) );
- SdrObjListIter aIter( rSdrPage, IM_FLAT );
+ SdrObjListIter aIter( rSdrPage, SdrIterMode::Flat );
while( aIter.IsMore() )
{
SdrObject* pObj( aIter.Next() );
@@ -628,7 +628,7 @@ namespace docfunc
{
const SdrPage& rSdrPage( *(p_rDoc.getIDocumentDrawModelAccess().GetDrawModel()->GetPage( 0 )) );
- SdrObjListIter aIter( rSdrPage, IM_FLAT );
+ SdrObjListIter aIter( rSdrPage, SdrIterMode::Flat );
while( aIter.IsMore() )
{
SdrObject* pObj( aIter.Next() );
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index f4c58c47f6e3..a202c566c6c6 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -639,7 +639,7 @@ void SwDrawContact::GetTextObjectsFromFormat( std::list<SdrTextObj*>& rTextObjec
{
if ( dynamic_cast<const SdrObjGroup*>(pSdrO) != nullptr )
{
- SdrObjListIter aListIter( *pSdrO, IM_DEEPNOGROUPS );
+ SdrObjListIter aListIter( *pSdrO, SdrIterMode::DeepNoGroups );
//iterate inside of a grouped object
while( aListIter.IsMore() )
{
diff --git a/sw/source/core/frmedt/feshview.cxx b/sw/source/core/frmedt/feshview.cxx
index 50369c909715..d090efd4b726 100644
--- a/sw/source/core/frmedt/feshview.cxx
+++ b/sw/source/core/frmedt/feshview.cxx
@@ -1332,7 +1332,7 @@ const SdrObject* SwFEShell::GetBestObject( bool bNext, GotoObjFlags eType, bool
OSL_ENSURE( pList, "No object list to iterate" );
- SdrObjListIter aObjIter( *pList, bFlat ? IM_FLAT : IM_DEEPNOGROUPS );
+ SdrObjListIter aObjIter( *pList, bFlat ? SdrIterMode::Flat : SdrIterMode::DeepNoGroups );
while ( aObjIter.IsMore() )
{
SdrObject* pObj = aObjIter.Next();
@@ -1382,7 +1382,7 @@ const SdrObject* SwFEShell::GetBestObject( bool bNext, GotoObjFlags eType, bool
(aCurPos.getX() < aPos.getX())) ) // " reverse
{
aBestPos = Point( nTmp, nTmp );
- SdrObjListIter aTmpIter( *pList, bFlat ? IM_FLAT : IM_DEEPNOGROUPS );
+ SdrObjListIter aTmpIter( *pList, bFlat ? SdrIterMode::Flat : SdrIterMode::DeepNoGroups );
while ( aTmpIter.IsMore() )
{
SdrObject* pTmpObj = aTmpIter.Next();
diff --git a/sw/source/core/unocore/unodraw.cxx b/sw/source/core/unocore/unodraw.cxx
index 977e95bcc9e0..b608315d90ce 100644
--- a/sw/source/core/unocore/unodraw.cxx
+++ b/sw/source/core/unocore/unodraw.cxx
@@ -963,7 +963,7 @@ SwXShape::SwXShape(uno::Reference< uno::XInterface > & xShape) :
void SwXShape::AddExistingShapeToFormat( SdrObject& _rObj )
{
- SdrObjListIter aIter( _rObj, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( _rObj, SdrIterMode::DeepNoGroups );
while ( aIter.IsMore() )
{
SdrObject* pCurrent = aIter.Next();
diff --git a/sw/source/uibase/dochdl/swdtflvr.cxx b/sw/source/uibase/dochdl/swdtflvr.cxx
index ca7e34774ac8..288144bc90fb 100644
--- a/sw/source/uibase/dochdl/swdtflvr.cxx
+++ b/sw/source/uibase/dochdl/swdtflvr.cxx
@@ -640,7 +640,7 @@ bool SwTransferable::WriteObject( tools::SvRef<SotStorageStream>& xStream,
for(sal_uInt16 a(0); a < pModel->GetPageCount(); a++)
{
const SdrPage* pPage = pModel->GetPage(a);
- SdrObjListIter aIter(*pPage, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pPage, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
diff --git a/sw/source/uibase/shells/drwbassh.cxx b/sw/source/uibase/shells/drwbassh.cxx
index c937cc6582cc..30ccc404d51b 100644
--- a/sw/source/uibase/shells/drwbassh.cxx
+++ b/sw/source/uibase/shells/drwbassh.cxx
@@ -604,7 +604,7 @@ IMPL_LINK_TYPED( SwDrawBaseShell, CheckGroupShapeNameHdl, AbstractSvxObjectNameD
{
bRet = true;
SwDrawModel* pModel = rSh.getIDocumentDrawModelAccess().GetDrawModel();
- SdrObjListIter aIter( *(pModel->GetPage(0)), IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *(pModel->GetPage(0)), SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pTempObj = aIter.Next();
diff --git a/include/svx/svditer.hxx b/include/svx/svditer.hxx
index cfbec5fe920b..f4d935989ead 100644
--- a/include/svx/svditer.hxx
+++ b/include/svx/svditer.hxx
@@ -30,10 +30,10 @@ class SdrObject;
class SdrMarkList;
// SdrObjListIter methods:
-// IM_FLAT : Flat over the list
-// IM_DEEPWITHGROUPS : With recursive descent parser, Next() also returns group objects
-// IM_DEEPNOGROUPS : With recursive descent parser, Next() returns no group objects
-enum SdrIterMode { IM_FLAT, IM_DEEPWITHGROUPS, IM_DEEPNOGROUPS};
+// SdrIterMode::Flat : Flat over the list
+// SdrIterMode::DeepWithGroups : With recursive descent parser, Next() also returns group objects
+// SdrIterMode::DeepNoGroups : With recursive descent parser, Next() returns no group objects
+enum class SdrIterMode { Flat, DeepWithGroups, DeepNoGroups };
class SVX_DLLPUBLIC SdrObjListIter
{
@@ -46,7 +46,7 @@ class SVX_DLLPUBLIC SdrObjListIter
void ImpProcessObj(SdrObject* pObj, SdrIterMode eMode, bool bUseZOrder);
public:
- explicit SdrObjListIter(const SdrObjList& rObjList, SdrIterMode eMode = IM_DEEPNOGROUPS, bool bReverse = false);
+ explicit SdrObjListIter(const SdrObjList& rObjList, SdrIterMode eMode = SdrIterMode::DeepNoGroups, bool bReverse = false);
/** This variant lets the user choose the order in which to travel over
the objects.
@param bUseZOrder
@@ -54,14 +54,14 @@ public:
Otherwise the navigation position as returned by
SdrObject::GetNavigationPosition() is used.
*/
- SdrObjListIter(const SdrObjList& rObjList, bool bUseZOrder, SdrIterMode eMode = IM_DEEPNOGROUPS);
+ SdrObjListIter(const SdrObjList& rObjList, bool bUseZOrder, SdrIterMode eMode = SdrIterMode::DeepNoGroups);
/* SJ: the following function can now be used with every
SdrObject and is no longer limited to group objects */
- explicit SdrObjListIter(const SdrObject& rObj, SdrIterMode eMode = IM_DEEPNOGROUPS);
+ explicit SdrObjListIter(const SdrObject& rObj, SdrIterMode eMode = SdrIterMode::DeepNoGroups);
/** Iterates over a list of marked objects received from the SdrMarkView. */
- explicit SdrObjListIter(const SdrMarkList& rMarkList, SdrIterMode eMode = IM_DEEPNOGROUPS);
+ explicit SdrObjListIter(const SdrMarkList& rMarkList, SdrIterMode eMode = SdrIterMode::DeepNoGroups);
void Reset() { mnIndex = (mbReverse ? maObjList.size() : 0L); }
bool IsMore() const { return (mbReverse ? mnIndex != 0 : ( mnIndex < maObjList.size())); }
diff --git a/svx/source/svdraw/svdsnpv.cxx b/svx/source/svdraw/svdsnpv.cxx
index c7b34b47e510..e2259d4aeafb 100644
--- a/svx/source/svdraw/svdsnpv.cxx
+++ b/svx/source/svdraw/svdsnpv.cxx
@@ -331,8 +331,8 @@ SdrSnap SdrSnapView::SnapPos(Point& rPnt, const SdrPageView* pPV) const
sal_uIntPtr nMaxPointSnapCount=200;
sal_uIntPtr nMaxFrameSnapCount=200;
- // go back to IM_DEEPNOGROUPS runthrough for snap to object comparisons
- SdrObjListIter aIter(*pPV->GetPage(),IM_DEEPNOGROUPS,true);
+ // go back to SdrIterMode::DeepNoGroups runthrough for snap to object comparisons
+ SdrObjListIter aIter(*pPV->GetPage(),SdrIterMode::DeepNoGroups,true);
while (aIter.IsMore() && (nMaxPointSnapCount>0 || nMaxFrameSnapCount>0)) {
SdrObject* pO=aIter.Next();